package bloop
import "cmd/compile/internal/bloop"
Index ¶
Functions ¶
func BloopWalk ¶
BloopWalk performs a walk on all functions in the package if it imports testing and wrap the results of all qualified statements in a runtime.KeepAlive intrinsic call. See package doc for more details.
for b.Loop() {...}
loop's body.
Source Files ¶
- Version
- v1.26.0-rc.1
- Published
- Dec 15, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 2 minutes ago –
Tools for package owners.